==> apiconnect-cli-apis-2.1.0.tgz: package/lib/util/util.js <==
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-apis
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
var fs = require('fs');
var f = require('util').format;

function getName(nameVersion) {
  var token = nameVersion.split(':');
  return token[0];
}

function getVersion(nameVersion) {
  var token = nameVersion.split(':');
  return token[1] || null;
}

function getNameVersionUrlPart(replace) {
  var replaceToken = replace.split(':');
  var urlPart = 'name=' + replaceToken[0];
  if (replaceToken.length >= 2) {
    urlPart = urlPart + '&version=' + replaceToken[1];
  }

  return urlPart;
}

function validateWriteFile(desPath, content, overWrite) {
  if (fs.existsSync(desPath) && !overWrite) {
    throw new Error(f('The file %s already exists.', desPath));
  } else {
    fs.writeFileSync(desPath, content);
  }
}

function isProductFile(path) {
  if (!path) {
    return false;
  }

  var i = path.lastIndexOf('.');
  if (i < 0) {
    return false;
  }

  if ((path.substr(i) === '.yml') || (path.substr(i) === '.yaml')) {
    return true;
  }

  return false;
}

module.exports.getName = getName;
module.exports.getVersion = getVersion;
module.exports.getNameVersionUrlPart = getNameVersionUrlPart;
module.exports.validateWriteFile = validateWriteFile;
module.exports.isProductFile = isProductFile;

==> apiconnect-cli-apis-2.5.6.tgz: package/lib/util/util.js <==
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2016, 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
// Node module: apiconnect-cli-apis

var fs = require('fs');
var g = require('strong-globalize')();

function getName(nameVersion) {
  var token = nameVersion.split(':');
  return token[0];
}

function getVersion(nameVersion) {
  var token = nameVersion.split(':');
  return token[1] || null;
}

function getNameVersionUrlPart(replace) {
  var replaceToken = replace.split(':');
  var urlPart = 'name=' + replaceToken[0];
  if (replaceToken.length >= 2) {
    urlPart = urlPart + '&version=' + replaceToken[1];
  }

  return urlPart;
}

function validateWriteFile(desPath, content, overWrite) {
  if (fs.existsSync(desPath) && !overWrite) {
    throw new Error(g.f('The file %s already exists.', desPath));
  } else {
    fs.writeFileSync(desPath, content);
  }
}

function isProductFile(path) {
  if (!path) {
    return false;
  }

  var i = path.lastIndexOf('.');
  if (i < 0) {
    return false;
  }

  if ((path.substr(i) === '.yml') || (path.substr(i) === '.yaml')) {
    return true;
  }

  return false;
}

function arrayContains(array, element) {
  return array.indexOf(element) > -1;
};

module.exports.getName = getName;
module.exports.getVersion = getVersion;
module.exports.getNameVersionUrlPart = getNameVersionUrlPart;
module.exports.validateWriteFile = validateWriteFile;
module.exports.isProductFile = isProductFile;
module.exports.arrayContains = arrayContains;
